@@ -38,7 +38,7 @@ def is_float(string):
 
 class EManafa(Service):
 	"""docstring for GreenStats"""
-	def __init__(self, power_profile=None, timezone=None, resources_dir="resources"):
+	def __init__(self, power_profile=None, timezone=None, resources_dir=MANAFA_RESOURCES_DIR):
 		Service.__init__(self)
 		self.resources_dir = resources_dir
 		self.power_profile = power_profile if power_profile is not None else self.inferPowerProfile()
@@ -48,6 +48,7 @@ class EManafa(Service):
 		self.perf_events = None
 		self.perfetto = PerfettoService()
 		self.timezone = timezone if timezone is not None else self.__inferTimezone()
+		self.unplugged=False
 
 	def config(self, **kwargs):
 		pass
@@ -56,6 +57,7 @@ class EManafa(Service):
 		self.boot_time = get_last_boot_time()
 		self.batterystats.init(boot_time=self.boot_time)
 		self.perfetto.init(boot_time=self.boot_time)
+		self.__unplug_if_fully_charged()
 		
 	def start(self):
 		self.batterystats.start()
@@ -64,6 +66,8 @@ class EManafa(Service):
 	def stop(self):
 		b_out = self.batterystats.stop()
 		p_out = self.perfetto.stop()
+		if self.unplugged:
+			self.__plug_back()
 		return b_out, p_out
 	
 	def clean(self):
@@ -165,16 +169,16 @@ class EManafa(Service):
 		return lasti,lasti
 
 
-	def __extractPowerProfile(self, resources_dir, filename):
+	def __extractPowerProfile(self, filename):
 		# extracting power_profile.xml from device
-		res, suc, _ = execute_shell_command("adb pull /system/framework/framework-res.apk %s" % resources_dir)
+		res, suc, _ = execute_shell_command("adb pull /system/framework/framework-res.apk %s" % self.resources_dir)
 		if res==0:
-			cmd = """java -jar {res_dir}/apktool_2.4.0.jar d -s {res_dir}/framework-res.apk -o {res_dir}/out_jar_dir/""".format(res_dir=resources_dir)
-			res, suc, _ = execute_shell_command(cmd)
-			pp_file = resources_dir + "/out_jar_dir/res/xml/power_profile.xml"
+			cmd = """java -jar {res_dir}/apktool_2.4.0.jar d -s {res_dir}/framework-res.apk -f -o {res_dir}/out_jar_dir/""".format(res_dir=self.resources_dir)
+			res, suc, v = execute_shell_command(cmd)
+			pp_file = self.resources_dir + "/out_jar_dir/res/xml/power_profile.xml"
 			if res==0:
 				# cp to profiles, remove out_jar_dir and framework-res.apk
-				res,_,_=  execute_shell_command("cp {extracted_file} \"{res_dir}/profiles/{new_file}\" ; rm -rf {res_dir}/out_jar_dir {res_dir}/framework-res.apk".format(extracted_file=pp_file, new_file=filename, res_dir=resources_dir ))
+				res,_,_=  execute_shell_command("cp {extracted_file} \"{res_dir}/profiles/{new_file}\" ; rm -rf {res_dir}/out_jar_dir {res_dir}/framework-res.apk".format(extracted_file=pp_file, new_file=filename, res_dir=self.resources_dir ))
 				if res ==0:
 					return filename
 
@@ -189,7 +193,8 @@ class EManafa(Service):
 				return matching_profiles[0]
 			else:
 				# if power profile not present in profiles directory, extract from device
-				power_profile = self.__extractPowerProfile(self.resources_dir, model_profile_file)
+				power_profile = self.__extractPowerProfile( model_profile_file)
+				print(power_profile)
 				return power_profile
 		else:
 			return DEFAULT_PROFILE
@@ -202,6 +207,25 @@ class EManafa(Service):
 		log("Using timezone: %s" % default_tz)
 		return "UTC" if default_tz == "WEST" else default_tz
 
+	def __unplug_if_fully_charged(self):
+		# battery stats file comes empty when battery level == 100
+		# using adb to trick device to think it is not charging th battery
+		res, o, e = execute_shell_command("adb shell dumpsys battery | grep level | grep 100")
+		has_full_charge = res ==0 and "100" in o
+		if has_full_charge:
+			#mock unplug
+			res, o, e = execute_shell_command("adb shell dumpsys battery unplug")
+			if res == 0:
+				self.unplugged=True
+				log("virtually unplugging battery charger while running (battery == 100)", LogSeverity.WARNING)
+
+	def __plug_back(self):
+		res, o, e = execute_shell_command("adb shell dumpsys battery reset")
+		self.unplugged=False
+
+
+
+
 
 def have_connected_devices():
 	res,o,e = execute_shell_command("adb devices -l | grep -v attached")
@@ -209,20 +233,18 @@ def have_connected_devices():
 
 
 if __name__ == '__main__':
-	default_resources_dir = "resources"
 	parser = argparse.ArgumentParser()
 	parser.add_argument("-p", "--profile", default=None, type=str)
 	parser.add_argument("-t", "--timezone", default=None, type=str)
 	parser.add_argument("-pft", "--perfettofile", default=None, type=str)
 	parser.add_argument("-bts", "--batstatsfile", default=None, type=str)
 	args = parser.parse_args()
-
 	has_device_conn = have_connected_devices()
 	invalid_file_args = (args.perfettofile is None or args.batstatsfile is None )
 	if not has_device_conn and invalid_file_args:
 		log("Fatal error. No connected devices and result files submittted for analysis", LogSeverity.FATAL)
 		exit(-1)
-	g = EManafa(power_profile=args.profile, timezone=args.timezone, resources_dir=default_resources_dir)
+	g = EManafa(power_profile=args.profile, timezone=args.timezone, resources_dir=MANAFA_RESOURCES_DIR)
 	if has_device_conn and invalid_file_args:
 		g.init()
 		g.start()
